@@ -17,9 +17,17 @@ class Environment(object):
     """
     client = docker_client()
 
-    def __init__(self, env_name):
+    def __init__(self, env_name, image_name):
         self.env_name = env_name
+        self._image_name = image_name
+        self._service_dict = self._get_service_dict(image_name)
+        self._project = Project.from_dicts(self.env_name, self._service_dict, self.client)
+        for service in self._project.get_services():
+            setattr(self, service.name, Service(service.name, service, self))
 
+    @property
+    def service_list(self):
+        return [Service(service.name, service, self) for service in self._project.get_services()]
 
     @classmethod
     def create_environment(cls, env_type, env_name, image_name=None):
@@ -27,11 +35,13 @@ class Environment(object):
         Create an environment object
 
         :param env_type: string cluster|dst|shc
-        :param env_name: string identifier of an environment, the environment name will be "env_name"_"env_type"
+        :param env_name: string identifier of an environment, the environment name will be [env_name]_[env_type]
         :param image_name: string   if not provided will use default which is '10.66.128.203:49153/coreqa/splunk:fig'
+
         :return:    environment object
 
-        >>> import rider
+
+        >>> from rider.environment import Environment
         >>> myEnv = Environment.create_environment("cluster", "jacktestapi2")
         """
         if image_name is None:
@@ -48,7 +58,13 @@ class Environment(object):
     @classmethod
     def get_environments(cls):
         """
-        Return all environments
+        Return all environments object
+
+        :return:    list of environment objects
+
+
+        >>> from rider.environment import Environment
+        >>> env_list = Environment.get_environments()
         """
 
         all_environment = []
@@ -65,6 +81,15 @@ class Environment(object):
 
     @classmethod
     def get_environment_by_name(cls, name):
+        """
+        Return the environment object specified by name ([env_name]_[env_type])
+        :param name: string name = env_name+"_"+env_type
+
+        :return:    environment object
+
+        >>> from rider.environment import Environment
+        >>> env = Environment.get_environments('jacktestapi2_cluster')
+        """
 
         for env in cls.get_environments():
             if env.env_name == name:
@@ -86,9 +111,16 @@ class Environment(object):
 
 
     def get_service_names(self):
+        """
+        Get list of service name belong to environment
+        :return: list of service name
 
+        >>> from rider.environment import  Environment
+        >>> env = Environment.get_environments('jacktestapi2_cluster')
+        >>> services_name_list = env.get_service_names()
+        """
         service_name = []
-        for service in self._services:
+        for service in self.service_list:
             if service.name not in service_name:
                 service_name.append(service.name)
 
@@ -117,14 +149,7 @@ class ClusterEnvironment(Environment):
     env_type = "cluster"
 
     def __init__(self, env_name, image_name):
-        super(ClusterEnvironment, self).__init__(env_name)
-        # add your init functions
-        self._image_name = image_name
-        self._service_dict = self._get_service_dict(image_name)
-        self._project = Project.from_dicts(self.env_name, self._service_dict, self.client)
-        self._services = self._project.get_services()
-        for service in self._services:
-            setattr(self, service.name, Service(service, self))
+        super(ClusterEnvironment, self).__init__(env_name, image_name)
 
 
 class DistributedEnvironment(Environment):
@@ -172,23 +197,24 @@ ENV_DICT_MAPPING = {
          'links': ['master'], u'name': 'indexer'}]
 }
 
-# if __name__ == "__main__":
-# os.environ["FIG_FILE"] = "/Users/weiwang/work/github/rider/rider/pkg/fig.yml"
-# os.environ["DOCKER_HOST"] = 'tcp://192.168.59.103:2376'
-# os.environ["DOCKER_TLS_VERIFY"] = '1'
-#     os.environ["DOCKER_CERT_PATH"] = '/Users/weiwang/.boot2docker/certs/boot2docker-vm'
-#     testenv = Environment.get_environment_by_name('jacktestapi2')
-#     testenv = Environment.get_environments()
-#     print testenv[0].indexer.machines
-#
-#     myEnv = Environment.create_environment("cluster", "jacktestapi2")
-#
-#     # myEnv.get_service_names()
-#
-#     myEnv.up()
-#     myEnv.indexer.scale(2)
-#
-#     print myEnv.indexer.machines[0].name
-#     Environment.get_environments()
-#     Environment.get_environment_by_name('jacktestapi2')
-#     print 1
+if __name__ == "__main__":
+    # os.environ["FIG_FILE"] = "/Users/weiwang/work/github/rider/rider/pkg/fig.yml"
+    # os.environ["DOCKER_HOST"] = 'tcp://192.168.59.103:2376'
+    # os.environ["DOCKER_TLS_VERIFY"] = '1'
+    # os.environ["DOCKER_CERT_PATH"] = '/Users/weiwang/.boot2docker/certs/boot2docker-vm'
+    # testenv = Environment.get_environment_by_name('jacktestapi2')
+    # testenv = Environment.get_environments()
+    # print testenv[0].indexer.machines
+
+    myEnv = Environment.create_environment("cluster", "jacktestapi2")
+
+    # myEnv.get_service_names()
+    #
+    myEnv.up()
+    # myEnv.indexer.scale(2)
+    #
+    # print myEnv.indexer.machines[0].name
+    # Environment.get_environments()
+    env = Environment.get_environment_by_name('jacktestapi2_cluster')
+    print env.service_list
+    print 1
